@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.801';
+our $VERSION = '1.802';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -369,7 +369,7 @@ MCE::Loop - Parallel loop model for building creative loops
 
 =head1 VERSION
 
-This document describes MCE::Loop version 1.801
+This document describes MCE::Loop version 1.802
 
 =head1 DESCRIPTION
 
@@ -525,13 +525,10 @@ The following list options which may be overridden when loading the module.
        thaw => \&decode_sereal          # \&Storable::thaw
    ;
 
-There is a simpler way to enable Sereal. The following will attempt to use
-Sereal if available, otherwise defaults to Storable for serialization.
+From MCE 1.8 onwards, Sereal 3.008+ is loaded automatically if available with
+Perl 5.12 or later. Specify C<Sereal => 0> if Storable is desired instead.
 
-   use MCE::Loop Sereal => 1;
-
-From MCE 1.800 onwards, this is done automatically if Sereal 3.008 or later
-is installed. Specify Sereal => 0 if Storable is desired.
+   use MCE::Loop Sereal => 0;
 
 =head1 CUSTOMIZING MCE
 
